# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType


class Link(AWSObject):
    """
    `Link <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-oam-link.html>`__
    """

    resource_type = "AWS::Oam::Link"

    props: PropsDictType = {
        "LabelTemplate": (str, False),
        "ResourceTypes": ([str], True),
        "SinkIdentifier": (str, True),
        "Tags": (dict, False),
    }


class Sink(AWSObject):
    """
    `Sink <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-oam-sink.html>`__
    """

    resource_type = "AWS::Oam::Sink"

    props: PropsDictType = {
        "Name": (str, True),
        "Policy": (dict, False),
        "Tags": (dict, False),
    }
